.. _user_guides:

User Guides
===========

The User Guides section covers different topics about SDV usage for different types of data:

.. toctree::
    :maxdepth: 3

    single_table/index
    relational/index
    timeseries/index
    evaluation/index
    benchmarking/index
